Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2058)

Unified Diff: tests/ColorFilterTest.cpp

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/CodexTest.cpp ('k') | tests/DashPathEffectTest.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/ColorFilterTest.cpp
diff --git a/tests/ColorFilterTest.cpp b/tests/ColorFilterTest.cpp
index d0b0d77ed43a8a1547b07f501c49850194d65e0e..ee8f12b2fbc9387658a719f0ffc6717d8a4cce0e 100644
--- a/tests/ColorFilterTest.cpp
+++ b/tests/ColorFilterTest.cpp
@@ -42,12 +42,12 @@ static void test_composecolorfilter_limit(skiatest::Reporter* reporter) {
for (int i = 2; i < way_too_many; ++i) {
SkAutoTUnref<SkColorFilter> filter(make_filter());
parent.reset(SkColorFilter::CreateComposeFilter(parent, filter));
- if (NULL == parent) {
+ if (nullptr == parent) {
REPORTER_ASSERT(reporter, i > 2); // we need to have succeeded at least once!
return;
}
}
- REPORTER_ASSERT(reporter, false); // we never saw a NULL :(
+ REPORTER_ASSERT(reporter, false); // we never saw a nullptr :(
}
#define ILLEGAL_MODE ((SkXfermode::Mode)-1)
@@ -59,14 +59,14 @@ DEF_TEST(ColorFilter, reporter) {
SkColor color = rand.nextU();
// ensure we always get a filter, by avoiding the possibility of a
// special case that would return NULL (if color's alpha is 0 or 0xFF)
color = SkColorSetA(color, 0x7F);
SkColorFilter* cf = SkColorFilter::CreateModeFilter(color,
(SkXfermode::Mode)mode);
// allow for no filter if we're in Dst mode (its a no op)
- if (SkXfermode::kDst_Mode == mode && NULL == cf) {
+ if (SkXfermode::kDst_Mode == mode && nullptr == cf) {
continue;
}
« no previous file with comments | « tests/CodexTest.cpp ('k') | tests/DashPathEffectTest.cpp » ('j') | no next file with comments »
@@ -59,14 +59,14 @@ DEF_TEST(ColorFilter, reporter) {
SkColor color = rand.nextU();
// ensure we always get a filter, by avoiding the possibility of a
- // special case that would return NULL (if color's alpha is 0 or 0xFF)
+ // special case that would return nullptr (if color's alpha is 0 or 0xFF)
color = SkColorSetA(color, 0x7F);
SkColorFilter* cf = SkColorFilter::CreateModeFilter(color,

Powered by Google App Engine
This is Rietveld 408576698